#!/bin/sh
# \
# put something approprite for your unix box here
#
################################################################################
# $Revision: 1.1 $
#
# $Id: MD5Test.tcl,v 1.1 1999/09/02 04:30:17 brucea Exp $
# $Log: MD5Test.tcl,v $
# Revision 1.1  1999/09/02 04:30:17  brucea
# "Test Program for TCL MD5 extension"
#
#
# md5test.tcl
# ===========
#
# MD5 Test file (based on MD5 test suite included in RFC1421)
#
################################################################################

# regexp "^8.\[0-9\]+" [ info patchlevel ] whole tclVersion

if {[ string compare $tcl_platform(platform) "windows" ]!=0} {
   puts "library currently only available for windows - sorry!"
   puts "Email: brucea@cybernetics.demon.co.uk to suggest or supply port"
   exit 1
}

switch [ info patchlevel ] {
   "8.0.3" {
      set dll "md5_tcl803.dll"
   }
   "8.1.0" {
      set dll "md5_tcl81.dll"
   }
   "8.2.0" {
      set dll "md5_tcl82.dll"
   }
   default {
      puts "No dll available for TCL version [info patchlevel]"
      puts "Please try recompiling the source the installed version of TCL"
      puts "Email: brucea@cybernetics.demon.co.uk with suggestions or for further help"
      exit 1
   }
}

puts "loading MD5 library $dll"
load $dll


# ------------------------------------------------------------------------------
# PROCEDURE SECTION
# ------------------------------------------------------------------------------

# ------------------------------------------------------------------------------
# MAIN SECTION
# ------------------------------------------------------------------------------
# last modified: BSA 02-Sep-1999
# last modification: 1.1 - created


# MD5 test suite:
# MD5 ("") = d41d8cd98f00b204e9800998ecf8427e
# MD5 ("a") = 0cc175b9c0f1b6a831c399e269772661
# MD5 ("abc") = 900150983cd24fb0d6963f7d28e17f72
# MD5 ("message digest") = f96b697d7cb7938d525a2f31aaf161d0
# MD5 ("abcdefghijklmnopqrstuvwxyz") = c3fcd3d76192e4007dfb496cca67e13b
# MD5 ("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789") =
# d174ab98d277d9f5a5611c2c9f419d9f
# MD5 ("12345678901234567890123456789012345678901234567890123456789012345678901234567890") = 57edf4a22be3c955ac49da2e2107b67a


set tests {}

lappend tests "" 
lappend tests d41d8cd98f00b204e9800998ecf8427e

lappend tests "a"
lappend tests 0cc175b9c0f1b6a831c399e269772661

lappend tests "abc"
lappend tests 900150983cd24fb0d6963f7d28e17f72

lappend tests "message digest"
lappend tests f96b697d7cb7938d525a2f31aaf161d0

lappend tests "abcdefghijklmnopqrstuvwxyz" 
lappend tests c3fcd3d76192e4007dfb496cca67e13b

lappend tests "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789"
lappend tests d174ab98d277d9f5a5611c2c9f419d9f

lappend tests "12345678901234567890123456789012345678901234567890123456789012345678901234567890"
lappend tests 57edf4a22be3c955ac49da2e2107b67a

set i 0
foreach { input output } $tests {

   set signature [ MD5String $input ]

   puts "Test $i: InputString='$input'"
   puts "expected output: $output"
   puts "actual   output: $signature"

   if { $output != $signature } {
      puts "ERROR:- Result does not match the test suite"
      exit 1
   }

   incr i
}

puts "MD5 Test Suite passed successfully"


# End File md5test.tcl
