/******************************************************************************\
 * $Revision$
 *
 * $Id$
 * $Log$
 *
 * md5_tcl.cpp
 * ===========
 *
 * <description> - file created by Bruce S. O. Adams
 *
\******************************************************************************/

#include <tcl.h>
#include "global.h"
#include "md5.cpp"
#include <string.h>

/* convert 128bit signature in char[16] to hexidecimal string */
inline Tcl_Obj* CreateMD5String(unsigned char digest[16]) {
   char   md5buff[32];
   char*  md5string;
   unsigned int i;
   int hi;
   int low;

   md5string=md5buff;
   for (i = 0; i < 16; i++) {
      hi=(digest[i]&15);
      low=((digest[i]>>4)&15);
      md5string[1]=hi  + ((hi>9)?'a'-10:'0');
      md5string[0]=low + ((low>9)?'a'-10:'0');
      md5string+=2;
   }
   return Tcl_NewStringObj((char*)md5buff,32);
};

/* Based on MDString function in md5driver.c */
extern "C" int Tcl_MD5String(ClientData data,
			     Tcl_Interp* interp,
			     int objc,Tcl_Obj* CONST objv[]) {
   MD5_CTX context;
   unsigned char digest[16];
   unsigned char* string;
   unsigned int len;

   if (objc!=2) {
      Tcl_WrongNumArgs(interp,objc,objv,"<string>");
      return TCL_ERROR;
   };

   string=(unsigned char*)Tcl_GetStringFromObj(objv[1],(int*)&len);

   MD5Init (&context);
   MD5Update (&context, string, len);
   MD5Final (digest, &context);

   Tcl_SetObjResult(interp,CreateMD5String(digest));
   return TCL_OK;
}; /* Tcl_MD5String */


/* Digests a file and returns the result. */
extern "C" int Tcl_MD5File(ClientData data,
			   Tcl_Interp* interp,
			   int objc,
			   Tcl_Obj* CONST objv[]) {
   char *filename;
   FILE *file;
   MD5_CTX context;
   int len;
   unsigned char buffer[1024], digest[16];

   if (objc!=2) {
      Tcl_WrongNumArgs(interp,objc,objv,"<filename>");
      return TCL_ERROR;
   };

   filename=Tcl_GetStringFromObj(objv[1],(int*)&len);

   if ((file = fopen (filename, "rb")) == NULL) {
      char mesgbuf[2046];
      sprintf(mesgbuf,"%s can't be opened\n",filename);      
      Tcl_SetObjResult(interp,Tcl_NewStringObj((char*)mesgbuf,strlen(mesgbuf)));
      return TCL_ERROR;
   };

   MD5Init (&context);
   while (len = fread (buffer, 1, 1024, file))
      MD5Update (&context, buffer, len);
   MD5Final (digest, &context);
   fclose (file);

   Tcl_SetObjResult(interp,CreateMD5String(digest));
   return TCL_OK;

}; /* Tcl_MD5File */


extern "C" __declspec(dllexport) int Md_Init(Tcl_Interp* interp) {
   Tcl_CreateObjCommand(interp,"MD5File",Tcl_MD5File,
			(ClientData)NULL,(Tcl_CmdDeleteProc*)NULL);
   Tcl_CreateObjCommand(interp,"MD5String",Tcl_MD5String,
			(ClientData)NULL,(Tcl_CmdDeleteProc*)NULL);
   Tcl_PkgProvide(interp,"MD5","1.0");
   return TCL_OK;
}

  /*******/
 /* EOF */
/*******/
